Clazz.declarePackage("J.rendersurface");
Clazz.load(["J.rendersurface.PmeshRenderer"], "J.rendersurface.Plot3DRenderer", null, function(){
var c$ = Clazz.declareType(J.rendersurface, "Plot3DRenderer", J.rendersurface.PmeshRenderer);
});
;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
